<?php
/*
Plugin Name: LMS WooCommerce Paid Content
Description: Hide content based on user purchase status and roles.
Version: 1.5
Author: EasyToolsWP.com
*/

function paid_content_shortcode($atts, $content = null) {
    // Extract attributes and set default values
    $atts = shortcode_atts(array(
        'product_ids' => '',
        'user_type' => 'all_logged_in',
        'closedtext' => 'To access this content, you need to purchase:'
    ), $atts, 'paid_content');

    $user = wp_get_current_user();
    
    // Check if user is logged in
    if (is_user_logged_in()) {
        $user_id = $user->ID;
        $product_ids = array_filter(explode(',', $atts['product_ids']));
        $has_bought = empty($product_ids); // If no product IDs, assume the user has bought access by default

        foreach ($product_ids as $product_id) {
            if (wc_customer_bought_product('', $user_id, trim($product_id))) {
                $has_bought = true;
                break;
            }
        }

        // Check user role
        $allowed_roles = explode(',', $atts['user_type']);
        $user_roles = $user->roles;
        $role_match = array_intersect($allowed_roles, $user_roles);

        if ($has_bought && (empty($allowed_roles) || !empty($role_match))) {
            return do_shortcode($content);
        }
    }

    // If the user is not logged in or doesn't meet the conditions, show the closedtext message
    $products = array_filter(explode(',', $atts['product_ids']));
    $links = array();
    foreach ($products as $product_id) {
        if (!empty($product_id)) {
            $links[] = '<span style="display:block;"><a href="' . get_permalink(trim($product_id)) . '">' . get_the_title(trim($product_id)) . '</a></span>';
        }
    }
    
    // Build the message to display
    if (!empty($links)) {
        $message = $atts['closedtext'] . implode('', $links);
    } else {
        $message = $atts['closedtext'];
    }
    
    return $message;
}
add_shortcode('paid_content', 'paid_content_shortcode');
